==> igniteui-react-16.16.2.tgz: package/esm5/lib/Input.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { InputBase } from "./InputBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { InputDir_$type } from "./InputDir";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
/**
 * @hidden
 */
var Input = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Input, _super);
    function Input() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.change = null;
        return _this;
    }
    Input.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.g("change", function (a) { return _this.change(_this, ComponentValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.h("change");
        }
    };
    Object.defineProperty(Input.prototype, "al", {
        get: function () {
            var ret_ = this.f.c("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "z", {
        get: function () {
            var ret_ = this.f.c("dir");
            ret_ = enumGetBox(InputDir_$type, EnumUtil.getEnumValue(InputDir_$type, EnumUtil.parse(InputDir_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(InputDir_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(InputDir_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("dir", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ab", {
        get: function () {
            var ret_ = this.f.c("type");
            ret_ = enumGetBox(InputType_$type, EnumUtil.getEnumValue(InputType_$type, EnumUtil.parse(InputType_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(InputType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(InputType_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "aa", {
        get: function () {
            var ret_ = this.f.c("inputmode");
            ret_ = enumGetBox(InputInputmode_$type, EnumUtil.getEnumValue(InputInputmode_$type, EnumUtil.parse(InputInputmode_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(InputInputmode_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(InputInputmode_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("inputmode", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ak", {
        get: function () {
            var ret_ = this.f.c("pattern");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("pattern", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ad", {
        get: function () {
            var ret_ = this.f.c("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "af", {
        get: function () {
            var ret_ = this.f.c("minlength");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("minlength", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ae", {
        get: function () {
            var ret_ = this.f.c("maxlength");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("maxlength", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "aj", {
        get: function () {
            var ret_ = this.f.c("min");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("min", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ai", {
        get: function () {
            var ret_ = this.f.c("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ag", {
        get: function () {
            var ret_ = this.f.c("step");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("step", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ac", {
        get: function () {
            var ret_ = this.f.c("autofocus");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("autofocus", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ah", {
        get: function () {
            var ret_ = this.f.c("autocomplete");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.i("autocomplete", value_);
        },
        enumerable: false,
        configurable: true
    });
    Input.prototype.an = function () {
        this.nativeElement.reportValidity();
    };
    Input.prototype.ap = function (a) {
        this.nativeElement.setCustomValidity(a);
    };
    Input.prototype.ao = function () {
        this.nativeElement.select();
    };
    Input.prototype.ar = function (a) {
        this.nativeElement.stepUp(a);
    };
    Input.prototype.aq = function (a) {
        this.nativeElement.stepDown(a);
    };
    Input.$t = markType(Input, 'Input', InputBase.$);
    return Input;
}(InputBase));
export { Input };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/Input.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { InputBase } from "./InputBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { InputType_$type } from "./InputType";
import { InputInputmode_$type } from "./InputInputmode";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
/**
 * @hidden
 */
var Input = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Input, _super);
    function Input() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.change = null;
        return _this;
    }
    Input.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.r("change", function (a) { return _this.change(_this, ComponentValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("change");
        }
    };
    Object.defineProperty(Input.prototype, "am", {
        get: function () {
            var ret_ = this.f.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ab", {
        get: function () {
            var ret_ = this.f.n("type");
            ret_ = enumGetBox(InputType_$type, EnumUtil.getEnumValue(InputType_$type, this.f.f(InputType_$type, ret_)));
            return EnumUtil.getEnumValue(InputType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(InputType_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "aa", {
        get: function () {
            var ret_ = this.f.n("inputmode");
            ret_ = enumGetBox(InputInputmode_$type, EnumUtil.getEnumValue(InputInputmode_$type, this.f.f(InputInputmode_$type, ret_)));
            return EnumUtil.getEnumValue(InputInputmode_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(InputInputmode_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("inputmode", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "al", {
        get: function () {
            var ret_ = this.f.n("pattern");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("pattern", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ad", {
        get: function () {
            var ret_ = this.f.n("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "af", {
        get: function () {
            var ret_ = this.f.n("minlength");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("minlength", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ae", {
        get: function () {
            var ret_ = this.f.n("maxlength");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("maxlength", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ak", {
        get: function () {
            var ret_ = this.f.n("min");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("min", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "aj", {
        get: function () {
            var ret_ = this.f.n("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ag", {
        get: function () {
            var ret_ = this.f.n("step");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("step", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ac", {
        get: function () {
            var ret_ = this.f.n("autofocus");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("autofocus", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ai", {
        get: function () {
            var ret_ = this.f.n("autocomplete");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("autocomplete", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Input.prototype, "ah", {
        get: function () {
            var ret_ = this.f.n("tabIndex");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("tabIndex", value_);
        },
        enumerable: false,
        configurable: true
    });
    Input.prototype.ap = function () {
        this.nativeElement.reportValidity();
    };
    Input.prototype.ao = function () {
        this.nativeElement.checkValidity();
    };
    Input.prototype.ar = function (a) {
        this.nativeElement.setCustomValidity(this.f.i(a));
    };
    Input.prototype.aq = function () {
        this.nativeElement.select();
    };
    Input.prototype.at = function (a) {
        this.nativeElement.stepUp(this.f.i(a));
    };
    Input.prototype.as = function (a) {
        this.nativeElement.stepDown(this.f.i(a));
    };
    Input.$t = markType(Input, 'Input', InputBase.$);
    return Input;
}(InputBase));
export { Input };
